@@ -1,13 +1,11 @@
 """
 Route events to processors and backends.
 """
-import json
 import logging
 
 from eventtracking.backends.routing import RoutingBackend
-from eventtracking.backends.logger import DateTimeJSONEncoder
 from eventtracking.tasks import send_event
-
+from eventtracking.processors.exceptions import EventEmissionExit
 
 logger = logging.getLogger(__name__)
 
@@ -16,6 +14,9 @@ class AsyncRoutingBackend(RoutingBackend):
     """
     Route events to configured backends asynchronously.
 
+    Load the backend with name `backend_name` and use it to process and send
+    the event to configured nested backends.
+
     NB: This can only be safely configured as a top-level backend,
     since the Celery task has to look up the backend again by name.
     This backend can also only be used from the default tracker, since
@@ -33,8 +34,11 @@ class AsyncRoutingBackend(RoutingBackend):
             event (dict) :  Open edX generated analytics event
         """
         try:
-            json_event = json.dumps(event, cls=DateTimeJSONEncoder)
-            send_event.delay(self.backend_name, json_event)
-            logger.info('Scheduled celery task for event "{}" processing and routing'.format(event['name']))
-        except ValueError:
-            logger.error('Could not encode event "{}"'.format(event['name']))
+            processed_event = self.process_event(event)
+            logger.info('Successfully processed event "{}"'.format(event['name']))
+
+        except EventEmissionExit:
+            logger.info('[EventEmissionExit] skipping event {}'.format(event['name']))
+            return
+        send_event.delay(self.backend_name, processed_event)
+        logger.info('Scheduled celery task for event "{}" processing and routing'.format(event['name']))
