@@ -5,7 +5,11 @@ import logging
 from collections import OrderedDict
 from copy import deepcopy
 
-from eventtracking.processors.exceptions import EventEmissionExit
+from eventtracking.processors.exceptions import (
+    EventEmissionExit,
+    NoBackendEnabled,
+    NoTransformerImplemented,
+)
 
 
 LOG = logging.getLogger(__name__)
@@ -131,7 +135,14 @@ class RoutingBackend:
         for name, backend in self.backends.items():
             try:
                 backend.send(event)
+            except NoTransformerImplemented as exc:
+                LOG.info('[send_to_backends] No transformer has been implemented for edx event "%s", [%s]',
+                         event["name"], repr(exc))
+            except NoBackendEnabled as exc:
+                LOG.info('[send_to_backends] Failed to send edx event "%s" to "%s" backend. "%s" backend has'
+                         ' not been enabled, [%s]', event["name"], name, name, repr(exc)
+                         )
             except Exception:  # pylint: disable=broad-except
                 LOG.exception(
-                    'Unable to send event to backend: %s', name
+                    'Unable to send edx event "%s" to backend: %s', event["name"], name
                 )
