@@ -1,7 +1,6 @@
 """
 Test the async routing backend.
 """
-import json
 from unittest import TestCase
 
 from unittest.mock import sentinel, patch
@@ -25,15 +24,9 @@ class TestAsyncRoutingBackend(TestCase):
             'session': '0000'
         }
 
-    @patch('eventtracking.backends.async_routing.json.dumps', side_effect=ValueError)
-    @patch('eventtracking.backends.async_routing.send_event')
-    def test_json_encoding_error(self, mocked_send_event, _):
-        backend = AsyncRoutingBackend()
-        backend.send(self.sample_event)
-        mocked_send_event.assert_not_called()
-
     @patch('eventtracking.backends.async_routing.send_event')
     def test_successful_event_send(self, mocked_send_event):
         backend = AsyncRoutingBackend(backend_name='test')
+        processed_event = backend.process_event(self.sample_event)
         backend.send(self.sample_event)
-        mocked_send_event.delay.assert_called_once_with('test', json.dumps(self.sample_event))
+        mocked_send_event.delay.assert_called_once_with('test', processed_event)
