@@ -3,13 +3,11 @@ Runs invasive tests to ensure that the tracking system can communicate with
 an actual MongoDB instance.
 """
 
-from __future__ import absolute_import
 
 from datetime import datetime
 from uuid import uuid4
 
 from pytz import UTC
-from six.moves import range
 
 from eventtracking.backends.mongodb import MongoBackend
 from eventtracking.backends.tests import InMemoryBackend, IntegrationTestCase
@@ -24,7 +22,7 @@ class TestMongoIntegration(IntegrationTestCase):
     """
 
     def setUp(self):
-        super(TestMongoIntegration, self).setUp()
+        super().setUp()
         self.database_name = 'test_eventtracking_' + str(uuid4())
         self.mongo_backend = MongoBackend(database=self.database_name)
         self.memory_backend = InMemoryBackend()
@@ -35,7 +33,7 @@ class TestMongoIntegration(IntegrationTestCase):
 
     def tearDown(self):
         self.mongo_backend.connection.drop_database(self.database_name)
-        super(TestMongoIntegration, self).tearDown()
+        super().tearDown()
 
     def test_sequential_events(self):
         now = datetime.now(UTC)
