@@ -3,11 +3,9 @@ Runs performance tests to determine if a significant performance regression has
 been introduced to the MongoBackend.
 """
 
-from __future__ import absolute_import
 
 from uuid import uuid4
 
-from six.moves import range
 
 from eventtracking.backends.mongodb import MongoBackend
 from eventtracking.backends.tests import PerformanceTestCase
@@ -21,7 +19,7 @@ class TestBackendPerformance(PerformanceTestCase):
     """
 
     def setUp(self):
-        super(TestBackendPerformance, self).setUp()
+        super().setUp()
         self.database_name = 'perf_test_eventtracking_' + str(uuid4())
         self.mongo_backend = MongoBackend(database=self.database_name)
         self.tracker = Tracker({
@@ -30,7 +28,7 @@ class TestBackendPerformance(PerformanceTestCase):
 
     def tearDown(self):
         self.mongo_backend.connection.drop_database(self.database_name)
-        super(TestBackendPerformance, self).tearDown()
+        super().tearDown()
 
     def test_sequential_events(self):
         with self.assert_execution_time_less_than_threshold():
