@@ -1,7 +1,6 @@
 """
 New AppConfig for Django 1.8
 """
-from __future__ import absolute_import
 from django.apps import AppConfig
 
 
@@ -18,7 +17,7 @@ class EventTrackingConfig(AppConfig):
         """
         Initialize django specific tracker.
         """
-        super(EventTrackingConfig, self).ready()
+        super().ready()
         # pylint: disable=import-outside-toplevel
         from eventtracking.django.django_tracker import override_default_tracker
         override_default_tracker()
