@@ -1,8 +1,6 @@
 """
 Tests for celery tasks.
 """
-import json
-
 from unittest.mock import sentinel
 
 from django.test import TestCase
@@ -11,7 +9,6 @@ from django.test.utils import override_settings
 from eventtracking.tasks import send_event
 from eventtracking.tracker import get_tracker
 from eventtracking.django.django_tracker import override_default_tracker
-from eventtracking.processors.exceptions import EventEmissionExit
 
 
 MOCK_EVENT_TRACKING_BACKENDS = {
@@ -51,22 +48,13 @@ class TestAsyncSend(TestCase):
             'session': '0000'
         }
 
-    @override_settings(EVENT_TRACKING_BACKENDS=MOCK_EVENT_TRACKING_BACKENDS)
-    def test_event_emission_exit_exception(self):
-        override_default_tracker()
-        tracker = get_tracker()
-        tracker.backends['backend_1'].processors[0].side_effect = EventEmissionExit
-
-        send_event('backend_1', json.dumps(self.event))
-
-        tracker.backends['backend_1'].backends['nested_backend_1'].send.assert_not_called()
-
     @override_settings(EVENT_TRACKING_BACKENDS=MOCK_EVENT_TRACKING_BACKENDS)
     def test_successful_processing_and_sending_event(self):
         override_default_tracker()
         tracker = get_tracker()
         tracker.backends['backend_1'].processors[0].return_value = self.event
 
-        send_event('backend_1', json.dumps(self.event))
+        processed_event = tracker.backends['backend_1'].process_event(self.event)
+        send_event.apply(['backend_1', processed_event])
 
         tracker.backends['backend_1'].backends['nested_backend_1'].send.assert_called_once_with(self.event)
